@@ -1,6 +1,6 @@
 from datetime import datetime
 from itertools import groupby
-from typing import Optional
+from typing import Optional, Tuple
 
 from moscow_routes_parser.model import Stop, Stop_builder, Timetable_stop_time, Timetable_stop, Timetable, \
     Timetable_stop_builder, Timetable_builder
@@ -8,19 +8,20 @@ from moscow_routes_parser.model import Stop, Stop_builder, Timetable_stop_time,
 
 class Stop_impl(Stop):
 
-    def get_coords(self) -> (float, float):
+    def get_coords(self) -> Tuple[float, float]:
         return self.coords
 
     def get_name(self) -> str:
         return self.name
 
-    def __init__(self, name: str, coords: (float, float)):
+    def __init__(self, name: str, coords: Tuple[float, float]):
         self.coords = coords
         self.name = name
 
     def __eq__(self, other):
         return self.get_name() == other.get_name() and \
-               self.get_coords() == other.get_coords()
+               abs(self.get_coords()[0] - other.get_coords()[0]) <= 0.0000005 and \
+               abs(self.get_coords()[1] - other.get_coords()[1]) <= 0.0000005
 
     def __ne__(self, other):
         return not (self == other)
